Index: channels/chan_skinny.c
===================================================================
--- channels/chan_skinny.c	(revision 140937)
+++ channels/chan_skinny.c	(working copy)
@@ -2847,20 +2847,32 @@
 {
 	struct skinny_device *d;
 	struct skinny_line *l;
+	struct skinny_subchannel *sub;
+	int verbose = 0;
 
 	switch (cmd) {
 	case CLI_INIT:
-		e->command = "skinny show lines";
+		e->command = "skinny show lines [verbose]";
 		e->usage =
 			"Usage: skinny show lines\n"
-			"       Lists all lines known to the Skinny subsystem.\n";
+			"       Lists all lines known to the Skinny subsystem.\n"
+			"       If 'verbose' is specified, the output includes\n"
+			"       information about subs for each line.\n";
 		return NULL;
 	case CLI_GENERATE:
 		return NULL;
 	}
 
-	if (a->argc != 3)
+
+	if (a->argc == e->args) {
+		if (!strcasecmp(a->argv[e->args-1], "verbose")) {
+			verbose = 1;
+		} else {
+			return CLI_SHOWUSAGE;
+		}
+	} else if (a->argc != e->args - 1) {
 		return CLI_SHOWUSAGE;
+	}
 	
 	
 	ast_cli(a->fd, "Device Name          Instance Name                 Label               \n");
@@ -2873,6 +2885,15 @@
 				l->instance,
 				l->name,
 				l->label);
+			if (verbose) {
+				AST_LIST_TRAVERSE(&l->sub, sub, list) {
+					ast_cli(a->fd, "      %s> %s to %s\n",
+						(sub == l->activesub?"A":" "),
+						sub->owner->name,
+						(ast_bridged_channel(sub->owner)?ast_bridged_channel(sub->owner)->name:"")
+					);
+				}
+			}
 		}
 	}
 	AST_LIST_UNLOCK(&devices);
